@@ -1,15 +1,10 @@
-// sync'ed with help_mp-en.h 1.89
+// sync'ed with help_mp-en.h 1.95
 // Updates & fixes by pl <p_l@gmx.fr> & n.le gaillart <n@tourmentine.com>
 // Original translation by Firebird <firebird@chez.com>
 
 // ========================= Aide MPlayer ===========================
 
 #ifdef HELP_MP_DEFINE_STATIC
-static char* banner_text=
-"\n\n"
-"MPlayer " VERSION "(C) 2000-2003 Arpad Gereoffy (voir les DOCS)\n"
-"\n";
-
 static char help_text[]=
 "Utilisation:      mplayer [options] [url|rpertoire/]fichier\n"
 "\n"
@@ -139,7 +134,7 @@ static char help_text[]=
 #define MSGTR_AOComment "AO: Commentaire: %s\n"
 #define MSGTR_Video_NoVideo "Vido: Pas de vido\n"
 #define MSGTR_NotInitializeVOPorVO "\nFATAL: n'a pas pu initialiser les filtres vido (-vop) ou la sortie vido (-vo).\n"
-#define MSGTR_Paused "\n================= PAUSE =================\r"
+#define MSGTR_Paused "\n  =====  PAUSE  =====\r" // pas plus de 23 caractres (ligne d'tat pour les fichiers audio)
 #define MSGTR_PlaylistLoadUnable "\nNe peut pas charger la liste de lecture %s.\n"
 #define MSGTR_Exit_SIGILL_RTCpuSel \
 "- MPlayer a plant  cause d'une 'Instruction Illgale'.\n"\
@@ -163,7 +158,6 @@ static char help_text[]=
 
 // mencoder.c
 
-#define MSGTR_MEncoderCopyright "(C) 2000-2003 Arpad Gereoffy (voir les DOCS)\n"
 #define MSGTR_UsingPass3ControllFile "Utilisation du fichier de contrle de la passe 3\n"
 #define MSGTR_MissingFilename "\nNom de fichier manquant.\n\n"
 #define MSGTR_CannotOpenFile_Device "Ne peut pas ouvrir le fichier/priph.\n"
