@@ -6,11 +6,6 @@
 // ========================= MPlayer help ===========================
 
 #ifdef HELP_MP_DEFINE_STATIC
-static char* banner_text=
-"\n\n"
-"MPlayer " VERSION "(C) 2000-2003 Arpad Gereoffy (veja DOCS)\n"
-"\n";
-
 static char help_text[]=
 "Uso:   mplayer [opes] [url|caminho/]nome-do-arquivo\n"
 "\n"
@@ -170,7 +165,6 @@ static char help_text[]=
 
 // mencoder.c:
 
-#define MSGTR_MEncoderCopyright "(C) 2000-2003 Arpad Gereoffy (veja DOCS!)\n"
 #define MSGTR_UsingPass3ControllFile "Usando controle de arquivo pass3: %s\n"
 #define MSGTR_MissingFilename "\nFaltando nome do arquivo!\n\n"
 #define MSGTR_CannotOpenFile_Device "Impossvel abrir arquivo/dispositivo\n"
