@@ -129,7 +129,7 @@ static char help_text[]=
 #define MSGTR_AOComment "AO: : %s\n"
 #define MSGTR_Video_NoVideo ":  \n"
 #define MSGTR_NotInitializeVOPorVO "\nFATAL:      (-vop)    (-vo).\n"
-#define MSGTR_Paused "\n=================  =================\r"
+#define MSGTR_Paused "\n  =====    =====\r" // no more than 23 characters (status line for audio files)
 #define MSGTR_PlaylistLoadUnable "\n   playlist %s.\n"
 #define MSGTR_Exit_SIGILL_RTCpuSel \
 "- MPlayer  - ' '.\n"\
