@@ -648,7 +648,8 @@ int dvd_chapter_from_cell(dvd_priv_t* dvd,int title,int cell)
 int dvd_aid_from_lang(stream_t *stream, unsigned char* lang){
 dvd_priv_t *d=stream->priv;
 int code,i;
-  while(lang && strlen(lang)>=2){
+if(lang){
+  while(strlen(lang)>=2){
     code=lang[1]|(lang[0]<<8);
     for(i=0;i<d->nr_of_channels;i++){
 	if(d->audio_streams[i].language==code){
@@ -661,7 +662,8 @@ int code,i;
     lang+=2; while (lang[0]==',' || lang[0]==' ') ++lang;
   }
   mp_msg(MSGT_OPEN,MSGL_WARN,"No matching DVD audio language found!\n");
-  return -1;
+}
+return d->nr_of_channels ? d->audio_streams[0].id : -1;
 }
 
 int dvd_sid_from_lang(stream_t *stream, unsigned char* lang){
@@ -775,8 +777,8 @@ read_next:
 
 	    if(d->angle_seek){
 		int i,skip=0;
-#if defined(__GNUC__) && defined(__sparc__)
-		// workaround for a bug in the sparc version of gcc 2.95.X ... 3.2,
+#if defined(__GNUC__) && ( defined(__sparc__) || defined(hpux) )
+		// workaround for a bug in the sparc/hpux version of gcc 2.95.X ... 3.2,
 		// it generates incorrect code for unaligned access to a packed
 		// structure member, resulting in an mplayer crash with a SIGBUS
 		// signal.
