@@ -1,7 +1,7 @@
 /*
  TV Interface for MPlayer
  
- (C) Alex Beregszaszi <alex@naxine.org>
+ (C) Alex Beregszaszi <alex@fsn.hu>
  
  API idea based on libvo2
 
@@ -390,7 +390,7 @@ int demux_open_tv(demuxer_t *demuxer)
 
     if(!sh_video->fps)
     {
-        int tmp;
+        float tmp;
         if (funcs->control(tvh->priv, TVI_CONTROL_VID_GET_FPS, &tmp) != TVI_CONTROL_TRUE)
              sh_video->fps = 25.0f; /* on PAL */
         else sh_video->fps = tmp;
